@@ -12,12 +12,24 @@
 using namespace std;
 
 
-void error(const string& bugs_path, const string& bugs_line)
+bug::bug( std::string package_, std::string bugno_ )
 {
-	cerr << bugs_path << " is corrupted here: " << bugs_line << endl;
+        package = std::move(package_);
+        bugno = std::move(bugno_);
 }
 
-void read_bugs(map<string, owner>& bugs, const string& bugs_path)
+bool operator<(bug const& l, bug const &r)
+{
+    return l.bugno < r.bugno;
+}
+
+
+static void error(const string& bugs_path, const string& bugs_line)
+{
+	cerr << bugs_path << " is corrupted here: " << bugs_line << '\n';
+}
+
+void read_bugs(map<string, bug>& bugs, const string& bugs_path)
 {
 	ifstream bugs_file(bugs_path);
 	if (!bugs_file.is_open())
@@ -31,20 +43,20 @@ void read_bugs(map<string, owner>& bugs, const string& bugs_path)
 		if(!getline (ss, path, ' ')) return error(bugs_path, bugs_line);
 		if(!getline (ss, bug_nr, ' ')) return error(bugs_path, bugs_line);
 		if(!getline (ss, package, ' ')) return error(bugs_path, bugs_line);
-		owner bug(package, package, bug_nr);
-		bugs.insert(pair<string, owner>(path, bug));
+		bug entry(package, bug_nr);
+		bugs.emplace(std::move(path), std::move(entry));
 	}
 }
 
 #ifdef UNIT_TEST
-//clang++ -DUNIT_TEST bugs.cc owner.o -o test_bugs && ./test_bugs
+//clang++ -DUNIT_TEST bugs.cc owner.cc -o test_bugs && ./test_bugs
 int main()
 {
-	map<string, owner> bugs;
-        read_bugs(bugs, "bugs");
-	for(auto it = bugs.cbegin(); it != bugs.cend(); ++it)
+	map<string, bug> bugs;
+	read_bugs(bugs, "bugs");
+	for(const auto& bug: bugs)
 	{
-	    std::cout << it->first << ' ' << it->second.package << ' ' << it->second.bug << endl;
+	    std::cout << bug.first << ' ' << bug.second.package << ' ' << bug.second.bugno << '\n';
 	}
 }
 #endif
