@@ -29,8 +29,8 @@ else:
 
 cruft = dict()
 
-todo = set(bugs)
-done = set()
+todo: set[int] = set(bugs)
+done: set[int] = set()
 
 while todo:
     todo -= done
@@ -44,6 +44,9 @@ while todo:
             cruft[match] = (bug.bug_num, bug.source, bug.subject)
         for mail in bts.get_bug_log(bug.bug_num):
             for line in mail['body'].splitlines():
+                if '---- missing: dpkg ----' in line:
+                    # bug report contains cruft report, ignore from here
+                    break
                 for match in re.findall(re_cruft, line):
                     if match in FALSE_POSITIVES:
                         continue
@@ -58,6 +61,6 @@ while todo:
                     cruft[match] = (bug.bug_num, bug.source, line)
 
 for path,data in sorted(cruft.items()):
-    bug, package, raw = data
+    bug_nr, package, raw = data
     #print(raw)
-    print('%s %s %s' % (path, bug, package))
+    print('%s %s %s' % (path, bug_nr, package))
