@@ -42,6 +42,7 @@ int usage()
 	cerr << "usage: " << endl;
 	cerr << "  cpigs [-n] [NUMBER]  : default format" << endl;
 	cerr << "  cpigs -e             : export in ncdu format" << endl;
+	cerr << "                       : sample use: 'sudo cpigs -e | ncdu -f - --color dark'" << endl;
 	cerr << "  cpigs -c             : export in .csv format" << endl;
 	cerr << "  cpigs -C             : export in .csv format, also static files" << endl;
 	return 1;
@@ -133,7 +134,7 @@ void output_ncdu(vector<string>& cruft_db)
 		}
 	}
 
-	for(auto& part : last_dir) { cout << ']'; }
+	for(auto& part __attribute__((unused)): last_dir) { cout << ']'; }
 	cout << "]" << endl;
 }
 
@@ -160,14 +161,16 @@ int main(int argc, char *argv[])
 	}
 
 	vector<string> fs;
-	read_locate(fs, "/usr/share/cruft/ignore");
+	read_locate(fs, "/etc/cruft/ignore", "/");
 	elapsed("plocate");
 
 	if (csv) cout << "path;package;type;cruft;size" << endl;
 
 	vector<string> packages;
 	vector<string> dpkg;
-	read_dpkg(packages, dpkg, static_);
+	dpkg_start("/");
+	read_dpkg(packages, dpkg, static_, "/");
+	dpkg_end();
 	elapsed("dpkg");
 
 	vector<string> cruft_db;
@@ -195,8 +198,9 @@ int main(int argc, char *argv[])
 	};
 
 	vector<owner> globs;
-	read_filters("/etc/cruft/filters/", "/usr/share/cruft/ruleset", packages,globs);
-	read_explain("/etc/cruft/explain/", packages,globs);
+	read_filters("/etc/cruft/filters/", "/usr/share/cruft/ruleset", packages, globs);
+	setenv("CRUFT_ROOT", "", 0);
+	read_explain("/etc/cruft/explain/", packages, globs);
 	elapsed("read filters");
 
 	std::map<std::string, size_t> usage{{"UNKNOWN", 0}};
