@@ -2,11 +2,12 @@
 #include <string>
 using namespace std;
 
-void dpkg_start();
+void dpkg_start( const string& root_dir);
 void dpkg_end();
 int query(const char *path);
 
-int read_dpkg(vector<string>& packages, vector<string>& db, bool print_csv);
+int read_dpkg_header(vector<string>& packages);
+int read_dpkg(vector<string>& packages, vector<string>& db, bool print_csv, const string& root_dir);
 
 struct Diversion{
         string oldfile;
