@@ -7,7 +7,7 @@ int main()
 {
 	vector<string> packages;
 	vector<owner> explain;
-	dpkg_start();
+	dpkg_start("/");
 	read_dpkg_header(packages);
 	dpkg_end();
 	read_explain("/etc/cruft/explain/", packages, explain);
